api.assets.v1 package — Argus-Toolbelt 1.0 documentation

# api.assets.v1 package

## Submodules

## api.assets.v1.application module

Autogenerated API

`api.assets.v1.application.` `add_host_application`(hostID: str = None, roleID: int = None, name: str = None, description: str = None, properties: dict = None, cpe: str = None, sockets: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new HostApplication. (PUBLIC)

  Return type: | `dict`
  Parameters: | hostID (str) – Specify parent host. roleID (int) – Specify application role. name (str) – Name of application. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of application. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* cpe (str) – CPE of application. sockets (list) – Specify socket strings of the application. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 589, “limit”: 346, “responseCode”: 200, “count”: 795, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Own myself language crime dream everything.”, “messageTemplate”: “Price dog along fish college.”, “field”: “None available usually leader season under tend.”, “parameter”: {}, “timestamp”: 611513487}], “currentPage”: 383, “size”: 395}

`api.assets.v1.application.` `delete_host_application`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a HostApplication as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 559, “limit”: 649, “responseCode”: 200, “count”: 660, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Manager discuss second.”, “messageTemplate”: “Reach approach product than present ready make.”, “field”: “Smile teacher really evidence happy skin much.”, “parameter”: {}, “timestamp”: 961059112}], “currentPage”: 247, “size”: 274}

`api.assets.v1.application.` `get_host_application`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a HostApplication identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 96, “limit”: 554, “responseCode”: 200, “count”: 134, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Few new never seem especially chance smile guy.”, “messageTemplate”: “World art talk art city citizen ability.”, “field”: “Raise particularly customer I notice company only.”, “parameter”: {}, “timestamp”: 642160729}], “currentPage”: 437, “size”: 510}

`api.assets.v1.application.` `search_host_applications`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostApplications defined by a HostApplicationSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. applicationRole (list) – Search for applications by role (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 762, “limit”: 248, “responseCode”: 200, “count”: 567, “data”: [{“id”: “Water crime say hour.”, “name”: “Cassandra Williams”, “description”: “Production paper charge assume character.”, “createdTimestamp”: 151077714, “createdByUser”: {“id”: 644, “customerID”: 271, “userName”: “ksmith”, “name”: “Robert Walton”}, “lastUpdatedTimestamp”: 718761436, “lastUpdatedByUser”: {“id”: 423, “customerID”: 439, “userName”: “gordon20”, “name”: “Leslie Mcfarland”}, “deletedTimestamp”: 669027064, “deletedByUser”: {“id”: 384, “customerID”: 687, “userName”: “qtran”, “name”: “Natasha Carlson”}, “firstSeenTimestamp”: 1108907968, “lastSeenTimestamp”: 47884001, “flags”: [“CONTROLLED_VERSION”], “properties”: {“additionalProperties”: “Within nothing wear give animal.”}, “cpe”: “Range operation Republican hand.”, “sockets”: [“Society long watch southern everything should result.”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Coach arm major simple pressure music major.”, “messageTemplate”: “Analysis street effect maybe chair.”, “field”: “Whether thousand according campaign safe.”, “parameter”: {}, “timestamp”: 589826164}], “currentPage”: 364, “size”: 583}

`api.assets.v1.application.` `search_host_applications_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostApplications defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE includeFlag (list) – Include certain HostApplications in the search result based on set flags excludeFlag (list) – Exclude certain HostApplications from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 895, “limit”: 8, “responseCode”: 200, “count”: 19, “data”: [{“id”: “Black environmental inside process truth rate.”, “name”: “Donald Sanchez”, “description”: “Reveal make bed.”, “createdTimestamp”: 15953480, “createdByUser”: {“id”: 455, “customerID”: 728, “userName”: “chughes”, “name”: “Cheryl Mcbride”}, “lastUpdatedTimestamp”: 17927296, “lastUpdatedByUser”: {“id”: 265, “customerID”: 300, “userName”: “vpayne”, “name”: “Sarah Brandt”}, “deletedTimestamp”: 1506232453, “deletedByUser”: {“id”: 145, “customerID”: 955, “userName”: “bullocklaurie”, “name”: “David Campbell”}, “firstSeenTimestamp”: 709175847, “lastSeenTimestamp”: 389142263, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Ago risk financial human air.”}, “cpe”: “Loss item lead box production development pass.”, “sockets”: [“Behind try try nature.”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Science management war herself price bed rest.”, “messageTemplate”: “Prevent believe of right tree.”, “field”: “Affect second though.”, “parameter”: {}, “timestamp”: 1072210272}], “currentPage”: 559, “size”: 645}

`api.assets.v1.application.` `update_host_application`(id: str, roleID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, cpe: str = None, addSockets: list = None, deleteSockets: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing HostApplication. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID roleID (int) – Change application role. name (str) – Change application name. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change application description. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add properties to application (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Remove properties from application by key. cpe (str) – Change application CPE. addSockets (list) – Add sockets to application (list of protocol/port, e.g. tcp/80). deleteSockets (list) – Remove sockets from application (list of protocol/port, e.g. tcp/80). source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 738, “limit”: 0, “responseCode”: 200, “count”: 78, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Year citizen body it have their thing collection.”, “messageTemplate”: “Young air clearly.”, “field”: “However teach eight catch evening.”, “parameter”: {}, “timestamp”: 969310102}], “currentPage”: 316, “size”: 816}

## api.assets.v1.businessprocess module

Autogenerated API

`api.assets.v1.businessprocess.` `add_business_process`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 762, “limit”: 936, “responseCode”: 200, “count”: 996, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Change hit throughout our away.”, “messageTemplate”: “Go turn choice manage.”, “field”: “Too represent perform first education past.”, “parameter”: {}, “timestamp”: 437948328}], “currentPage”: 997, “size”: 399}

`api.assets.v1.businessprocess.` `attach_services_to_business_process`(id: str, serviceAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds multiple ServiceAssets to a BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID serviceAssetIDs (list) – Specify services to add to business process.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 776, “limit”: 597, “responseCode”: 200, “count”: 555, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Return drop certainly field culture alone claim.”, “messageTemplate”: “Real yard everybody product particularly ball old.”, “field”: “Paper similar fish sister within.”, “parameter”: {}, “timestamp”: 1095627978}], “currentPage”: 64, “size”: 309}

`api.assets.v1.businessprocess.` `delete_business_process`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a BusinessProcess as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 422, “limit”: 51, “responseCode”: 200, “count”: 159, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Past weight product.”, “messageTemplate”: “Successful traditional option foreign record people field why.”, “field”: “Old body threat professor better teach traditional.”, “parameter”: {}, “timestamp”: 982968066}], “currentPage”: 762, “size”: 176}

`api.assets.v1.businessprocess.` `detach_services_from_business_process`(id: str, serviceAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Removes multiple ServiceAssets from a BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID serviceAssetIDs (list) – Specify services to detach from business process.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 18, “limit”: 701, “responseCode”: 200, “count”: 993, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Win dinner trouble large move network allow.”, “messageTemplate”: “Simple rule use garden tough.”, “field”: “Candidate central story girl room.”, “parameter”: {}, “timestamp”: 590419036}], “currentPage”: 63, “size”: 649}

`api.assets.v1.businessprocess.` `get_business_process`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a BusinessProcess identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 921, “limit”: 634, “responseCode”: 200, “count”: 148, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Work view four if treatment right.”, “messageTemplate”: “Seem above star billion.”, “field”: “Spring difference television say me.”, “parameter”: {}, “timestamp”: 500804968}], “currentPage”: 47, “size”: 615}

`api.assets.v1.businessprocess.` `search_business_processes`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of BusinessProcesses defined by a BusinessProcessSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on business process). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 308, “limit”: 705, “responseCode”: 200, “count”: 386, “data”: [{“id”: “Source Congress job address close still old.”, “ownedByUser”: {“id”: 120, “customerID”: 587, “userName”: “jamiewilliams”, “name”: “Dr. Sandra Roberts”}, “name”: “Sarah Martin”, “description”: “Compare pick probably.”, “totalCvss”: 303, “vulnerabilitiesCount”: 213, “createdTimestamp”: 128776694, “createdByUser”: {“id”: 570, “customerID”: 289, “userName”: “aaron35”, “name”: “Stephanie Franklin”}, “lastUpdatedTimestamp”: 1109718976, “lastUpdatedByUser”: {“id”: 110, “customerID”: 732, “userName”: “ipitts”, “name”: “Andrew Gates”}, “deletedTimestamp”: 1150994004, “deletedByUser”: {“id”: 562, “customerID”: 86, “userName”: “stephen32”, “name”: “Julia Livingston”}, “flags”: [“HAS_HIGH_VULN”], “properties”: {“additionalProperties”: “Central least often teacher.”}, “services”: [{“id”: “Fine exist force military.”, “name”: “Christina Reyes”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Current unit stock run large gas.”, “messageTemplate”: “Pm maybe stay edge note school run body.”, “field”: “Land security drug mind seem hit say.”, “parameter”: {}, “timestamp”: 283869212}], “currentPage”: 357, “size”: 6}

`api.assets.v1.businessprocess.` `search_business_processes_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of BusinessProcesses defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain BusinessProcesses in the search result based on set flags excludeFlag (list) – Exclude certain BusinessProcesses from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 306, “limit”: 817, “responseCode”: 200, “count”: 354, “data”: [{“id”: “Attention involve run either church alone begin.”, “ownedByUser”: {“id”: 112, “customerID”: 329, “userName”: “jasmineryan”, “name”: “Danielle Wolf”}, “name”: “Sheila Scott”, “description”: “Relate watch live morning.”, “totalCvss”: 762, “vulnerabilitiesCount”: 433, “createdTimestamp”: 1383067243, “createdByUser”: {“id”: 834, “customerID”: 540, “userName”: “patelmelissa”, “name”: “Cheryl Lopez”}, “lastUpdatedTimestamp”: 327591381, “lastUpdatedByUser”: {“id”: 620, “customerID”: 539, “userName”: “iparsons”, “name”: “Angel Church”}, “deletedTimestamp”: 257878847, “deletedByUser”: {“id”: 745, “customerID”: 884, “userName”: “shannonortiz”, “name”: “Nicole Rose”}, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Media one parent especially cup machine discuss save.”}, “services”: [{“id”: “Individual drop four within black.”, “name”: “Anthony Brown”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Office total able join call small.”, “messageTemplate”: “Dog real center.”, “field”: “Do everyone treatment morning find.”, “parameter”: {}, “timestamp”: 1184560646}], “currentPage”: 468, “size”: 709}

`api.assets.v1.businessprocess.` `update_business_process`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 879, “limit”: 100, “responseCode”: 200, “count”: 478, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Here no option score particular growth.”, “messageTemplate”: “Those moment talk simply.”, “field”: “Three positive buy decide north week.”, “parameter”: {}, “timestamp”: 702748283}], “currentPage”: 519, “size”: 152}

## api.assets.v1.host module

Autogenerated API

`api.assets.v1.host.` `add_host_asset`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, operatingSystemCPE: str = None, ipAddresses: list = None, aliases: list = None, type: str = 'SERVER', source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new HostAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* operatingSystemCPE (str) – CPE of the host operating system. ipAddresses (list) – IP address(es) of the host. aliases (list) – Aliases (domain names) of the host. type (str) – Defines if host is a client or a server. (default SERVER) source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 921, “limit”: 562, “responseCode”: 200, “count”: 827, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Of baby factor notice letter perhaps.”, “messageTemplate”: “Loss charge garden performance military table scene.”, “field”: “Computer really past with.”, “parameter”: {}, “timestamp”: 930891971}], “currentPage”: 12, “size”: 313}

`api.assets.v1.host.` `bulk_update_host_asset`(assetVulnerabilityAddRequests: list = None, assetVulnerabilityUpdateRequests: list = None, assetVulnerabilityResolveRequests: list = None, assetVulnerabilityDeleteRequests: list = None, hostApplicationAddRequests: list = None, hostApplicationUpdateRequests: list = None, hostApplicationDeleteRequests: list = None, hostAssetAddRequests: list = None, hostAssetUpdateRequests: list = None, hostAssetDeleteRequests: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Performs multiple updates to HostAssets in a single transaction. (PUBLIC)

  Return type: | `dict`
  Parameters: | assetVulnerabilityAddRequests (list) – List of AssetVulnerabilityAddRequests. assetVulnerabilityUpdateRequests (list) – List of AssetVulnerabilityUpdateRequests. assetVulnerabilityResolveRequests (list) – List of AssetVulnerabilityResolveRequests. assetVulnerabilityDeleteRequests (list) – List of AssetVulnerabilityDeleteRequests. hostApplicationAddRequests (list) – List of HostApplicationAddRequests. hostApplicationUpdateRequests (list) – List of HostApplicationUpdateRequests. hostApplicationDeleteRequests (list) – List of HostApplicationDeleteRequests. hostAssetAddRequests (list) – List of HostAssetAddRequests. Adding vulnerabilities/applications to added hosts must be done in separate transaction. hostAssetUpdateRequests (list) – List of HostAssetUpdateRequests. hostAssetDeleteRequests (list) – List of HostAssetDeleteRequests. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 835, “limit”: 223, “responseCode”: 200, “count”: 54, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Music five itself find discussion claim else arrive.”, “messageTemplate”: “Per what action bill around.”, “field”: “Me walk environment describe relate civil image.”, “parameter”: {}, “timestamp”: 671373210}], “currentPage”: 652, “size”: 469}

`api.assets.v1.host.` `delete_host_asset`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a HostAsset as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 584, “limit”: 930, “responseCode”: 200, “count”: 529, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Special building later cold discover various ahead.”, “messageTemplate”: “Many travel source finally must yet affect century.”, “field”: “Woman spring newspaper direction.”, “parameter”: {}, “timestamp”: 322446910}], “currentPage”: 516, “size”: 417}

`api.assets.v1.host.` `get_host_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a HostAsset identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 23, “limit”: 95, “responseCode”: 200, “count”: 548, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Write doctor trial include loss evidence.”, “messageTemplate”: “Lot next hit prevent.”, “field”: “Control contain past both beat.”, “parameter”: {}, “timestamp”: 831486135}], “currentPage”: 241, “size”: 181}

`api.assets.v1.host.` `search_host_assets`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, type: str = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeVulnerabilityRawOutput: bool = 'False', includeVulnerabilityConclusion: bool = 'False', includeVulnerabilitySolution: bool = 'False', includeVulnerabilities: bool = 'False', includeApplications: bool = 'False', includeServices: bool = 'False', connectedToService: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostAssets defined by a HostAssetSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). type (str) – Restrict search to a specific type of host (client or server). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on host). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeVulnerabilityRawOutput (bool) – Include vulnerability rawOutput in result (default false). includeVulnerabilityConclusion (bool) – Include vulnerability conclusion in result (default false). includeVulnerabilitySolution (bool) – Include vulnerability solution in result (default false). includeVulnerabilities (bool) – Include host vulnerabilities in result (default false). includeApplications (bool) – Include host applications in result (default false). includeServices (bool) – Include related services in result (default false). connectedToService (bool) – If true, only return hosts connected to service(s). If false, return hosts not connected to any service. If not set, do not filter.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 468, “limit”: 746, “responseCode”: 200, “count”: 364, “data”: [{“id”: “Arm candidate cup meeting that same cover.”, “ownedByUser”: {“id”: 867, “customerID”: 657, “userName”: “kwhite”, “name”: “Donald Smith”}, “name”: “Alexander Morgan”, “description”: “Exactly training treatment fund scientist born hospital.”, “totalCvss”: 846, “vulnerabilitiesCount”: 216, “createdTimestamp”: 877203316, “createdByUser”: {“id”: 160, “customerID”: 415, “userName”: “lisahopkins”, “name”: “Brian Armstrong”}, “lastUpdatedTimestamp”: 826689143, “lastUpdatedByUser”: {“id”: 706, “customerID”: 289, “userName”: “dalvarez”, “name”: “William Garcia DDS”}, “deletedTimestamp”: 1397817734, “deletedByUser”: {“id”: 136, “customerID”: 381, “userName”: “brian77”, “name”: “Mary Brown”}, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Any class later analysis.”}, “firstSeenTimestamp”: 624667547, “lastSeenTimestamp”: 251487487, “lastScanTimestamp”: 1069334030, “ipAddresses”: [{“host”: false, “maskBits”: 245, “ipv6”: false, “multicast”: true, “public”: true, “address”: “Room effort fish choose door talk.”}], “aliases”: [{“fqdn”: “Career church fall fly human.”}], “services”: [{“id”: “Around recognize enough yard similar ready.”, “name”: “Haley Watts”}], “applications”: [{“id”: “Mean important whose local space.”, “name”: “Tony Harper”, “description”: “Similar say east visit piece we.”, “createdTimestamp”: 784063238, “lastUpdatedTimestamp”: 1493775590, “deletedTimestamp”: 1168521787, “firstSeenTimestamp”: 696407045, “lastSeenTimestamp”: 949118185, “flags”: [“MISSING_FROM_CVM”], “properties”: {“additionalProperties”: “Toward detail plan focus remain also hour one.”}, “cpe”: “Sport poor woman trial in.”, “sockets”: [“Science best weight prevent personal upon evening rest.”]}], “vulnerabilities”: [{“id”: “Question under again seat into.”, “vulnerabilityID”: “American important whom stand let.”, “references”: [“Director want coach organization collection.”], “name”: “Jamie Clark”, “description”: “Prove test institution his high.”, “conclusion”: “Foot pay store include.”, “solution”: “Play least step beautiful green assume audience.”, “rawOutput”: “Read challenge might human.”, “cvss”: 935, “createdTimestamp”: 228571607, “lastUpdatedTimestamp”: 1348122011, “deletedTimestamp”: 1107303135, “firstSeenTimestamp”: 763948522, “lastSeenTimestamp”: 325621442, “resolutionTimestamp”: 386705016, “resolutionComment”: “White role away where.”, “resolution”: “ACCEPTED”, “flags”: [“EXPLOIT_AVAILABLE”], “properties”: {“additionalProperties”: “Plan lead full democratic describe serious consumer.”}, “severity”: “high”, “socket”: “Contain anyone sea girl view then.”}], “operatingSystemCPE”: “Simply enough hotel through bar brother.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Upon career recognize create man report.”, “messageTemplate”: “Tonight analysis year even.”, “field”: “Message pick authority pattern then.”, “parameter”: {}, “timestamp”: 1437990416}], “currentPage”: 3, “size”: 285}

`api.assets.v1.host.` `search_host_assets_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of HostAssets defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain HostAssets in the search result based on set flags excludeFlag (list) – Exclude certain HostAssets from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 700, “limit”: 500, “responseCode”: 200, “count”: 891, “data”: [{“id”: “Make the rate within experience.”, “ownedByUser”: {“id”: 474, “customerID”: 120, “userName”: “matthew59”, “name”: “Michael Eaton”}, “name”: “Patrick Rowe”, “description”: “But painting public pressure support.”, “totalCvss”: 674, “vulnerabilitiesCount”: 606, “createdTimestamp”: 368869034, “createdByUser”: {“id”: 726, “customerID”: 945, “userName”: “ecannon”, “name”: “Maria Mccann”}, “lastUpdatedTimestamp”: 789883740, “lastUpdatedByUser”: {“id”: 298, “customerID”: 669, “userName”: “tara90”, “name”: “Paul White”}, “deletedTimestamp”: 1409145582, “deletedByUser”: {“id”: 312, “customerID”: 565, “userName”: “melaniejackson”, “name”: “Savannah Murray”}, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Green pay personal government white.”}, “firstSeenTimestamp”: 1432484279, “lastSeenTimestamp”: 584590728, “lastScanTimestamp”: 364529281, “ipAddresses”: [{“host”: true, “maskBits”: 942, “ipv6”: false, “multicast”: true, “public”: false, “address”: “Talk no notice trouble that.”}], “aliases”: [{“fqdn”: “Reason past real.”}], “services”: [{“id”: “Method method everyone.”, “name”: “Leslie Brown”}], “applications”: [{“id”: “Education author both talk determine cell thought.”, “name”: “Jenna Jenkins”, “description”: “Less prevent road agree increase like specific recent.”, “createdTimestamp”: 1290910322, “lastUpdatedTimestamp”: 630721363, “deletedTimestamp”: 1301247431, “firstSeenTimestamp”: 1022142152, “lastSeenTimestamp”: 273539809, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Compare shake under oil help too public.”}, “cpe”: “Authority direction responsibility argue way matter.”, “sockets”: [“Walk reduce level wide imagine clearly.”]}], “vulnerabilities”: [{“id”: “Effect white system hope beautiful in.”, “vulnerabilityID”: “Fast up history particular.”, “references”: [“Direction stage investment herself.”], “name”: “Christine Simpson”, “description”: “Occur interesting claim stock.”, “conclusion”: “Program approach drive strong person.”, “solution”: “Staff wait story six.”, “rawOutput”: “Day better employee create single which.”, “cvss”: 273, “createdTimestamp”: 906318467, “lastUpdatedTimestamp”: 456935280, “deletedTimestamp”: 310618325, “firstSeenTimestamp”: 1087407926, “lastSeenTimestamp”: 1409398477, “resolutionTimestamp”: 243910728, “resolutionComment”: “Color blood message increase describe current.”, “resolution”: “FALSE_POSITIVE”, “flags”: [“MISSING_FROM_CVM”], “properties”: {“additionalProperties”: “Small cup recognize.”}, “severity”: “medium”, “socket”: “Budget simply hold relationship audience reveal.”}], “operatingSystemCPE”: “Far least different enjoy far trouble.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Position which feeling opportunity suffer contain throw.”, “messageTemplate”: “Because doctor specific police enjoy.”, “field”: “Hope choice news debate.”, “parameter”: {}, “timestamp”: 1120411516}], “currentPage”: 565, “size”: 424}

`api.assets.v1.host.` `update_host_asset`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, type: str = None, operatingSystemCPE: str = None, addIpAddresses: list = None, deleteIpAddresses: list = None, addAliases: list = None, deleteAliases: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing HostAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key. type (str) – Change type of host (client or server). operatingSystemCPE (str) – Change CPE of host. addIpAddresses (list) – Add IP address(es) to host. deleteIpAddresses (list) – Delete IP address(es) from host. addAliases (list) – Add alias(es) (domain names) to host. deleteAliases (list) – Delete alias(es) from host. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 606, “limit”: 791, “responseCode”: 200, “count”: 193, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Whether discussion detail without.”, “messageTemplate”: “Field off system certainly anyone political public.”, “field”: “Single drive charge performance soon section why.”, “parameter”: {}, “timestamp”: 310775876}], “currentPage”: 761, “size”: 82}

## api.assets.v1.scan module

Autogenerated API

`api.assets.v1.scan.` `host_asset_bulk_scanned`(customerID: int = None, scannedRequests: list = None, scannedIpRanges: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks multiple HostAsset as scanned. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Define customer which was scanned. scannedRequests (list) – Set of host scan requests. scannedIpRanges (list) – Set of scanned IP address ranges as list of single IPs (1.1.1.1), CIDR networks (1.1.1.0/24) or ranges (1.1.1.1-1.1.1.2)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 60, “limit”: 377, “responseCode”: 200, “count”: 688, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Condition describe enter point.”, “messageTemplate”: “Purpose start southern own.”, “field”: “Return fine little compare offer federal.”, “parameter”: {}, “timestamp”: 1056255413}], “currentPage”: 912, “size”: 527}

`api.assets.v1.scan.` `host_asset_scanned`(customerID: int, ip: str, detectedVulnerabilities: list = None, detectedApplications: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a single HostAsset as scanned. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID ip (str) – IP address of scanned HostAsset detectedVulnerabilities (list) – Specify (vulnerabilityID, socket string) objects of detected vulnerabilities. detectedApplications (list) – Specify sockets of detected applications (e.g. tcp/80).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 227, “limit”: 702, “responseCode”: 200, “count”: 497, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Us necessary himself without.”, “messageTemplate”: “Wait environmental expert education build attention too.”, “field”: “Plant least nothing eat role hair professor worry.”, “parameter”: {}, “timestamp”: 1474863920}], “currentPage”: 782, “size”: 140}

## api.assets.v1.service module

Autogenerated API

`api.assets.v1.service.` `add_service_asset`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 777, “limit”: 978, “responseCode”: 200, “count”: 763, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Attention candidate hair and parent.”, “messageTemplate”: “Administration few reveal whole suffer both.”, “field”: “Scientist recent north person page.”, “parameter”: {}, “timestamp”: 1294900305}], “currentPage”: 605, “size”: 602}

`api.assets.v1.service.` `attach_hosts_to_service`(id: str, hostAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds multiple HostAssets to a ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID hostAssetIDs (list) – Specify hosts to add to service.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 403, “limit”: 906, “responseCode”: 200, “count”: 746, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Discuss staff million television popular message.”, “messageTemplate”: “Along newspaper security we scene create floor.”, “field”: “Event interest resource far decision.”, “parameter”: {}, “timestamp”: 618624990}], “currentPage”: 295, “size”: 887}

`api.assets.v1.service.` `delete_service_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a ServiceAsset as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 351, “limit”: 666, “responseCode”: 200, “count”: 335, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Course thousand child purpose my task.”, “messageTemplate”: “Box receive spend against.”, “field”: “Item hotel future lot probably hope indicate remember.”, “parameter”: {}, “timestamp”: 666318940}], “currentPage”: 569, “size”: 739}

`api.assets.v1.service.` `detach_hosts_from_service`(id: str, hostAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Removes multiple HostAssets from a ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID hostAssetIDs (list) – Specify hosts to detach from service.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 702, “limit”: 686, “responseCode”: 200, “count”: 874, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Continue food to month product.”, “messageTemplate”: “Part edge make daughter.”, “field”: “Whether sell compare.”, “parameter”: {}, “timestamp”: 501114757}], “currentPage”: 880, “size”: 353}

`api.assets.v1.service.` `get_service_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a ServiceAsset identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 69, “limit”: 62, “responseCode”: 200, “count”: 569, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Technology himself contain particularly show.”, “messageTemplate”: “Small follow section population this.”, “field”: “None simple community week fact woman sure war.”, “parameter”: {}, “timestamp”: 969438159}], “currentPage”: 410, “size”: 459}

`api.assets.v1.service.` `search_service_assets`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of ServiceAssets defined by a ServiceAssetSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on service). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 457, “limit”: 863, “responseCode”: 200, “count”: 406, “data”: [{“id”: “Study participant movie gun need pick.”, “ownedByUser”: {“id”: 123, “customerID”: 844, “userName”: “jeffreyjohnson”, “name”: “Robert Figueroa”}, “name”: “Joseph Smith”, “description”: “Bring realize sister pressure indeed sort.”, “totalCvss”: 768, “vulnerabilitiesCount”: 753, “createdTimestamp”: 382469074, “createdByUser”: {“id”: 930, “customerID”: 617, “userName”: “nicole19”, “name”: “Walter Smith”}, “lastUpdatedTimestamp”: 1342391645, “lastUpdatedByUser”: {“id”: 429, “customerID”: 609, “userName”: “nancylindsey”, “name”: “Allison Herrera”}, “deletedTimestamp”: 1148464781, “deletedByUser”: {“id”: 199, “customerID”: 645, “userName”: “kristine60”, “name”: “Brianna Bell”}, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Article event for.”}, “businessProcesses”: [{“id”: “Tell need strong space chair network walk report.”, “name”: “Jennifer Reeves”}], “hosts”: [{“id”: “Use point professional.”, “name”: “Sean Henry”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Main force moment commercial.”, “messageTemplate”: “Career production what.”, “field”: “Point assume this model indeed series.”, “parameter”: {}, “timestamp”: 1007224723}], “currentPage”: 956, “size”: 491}

`api.assets.v1.service.` `search_service_assets_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of ServiceAssets defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain ServiceAssets in the search result based on set flags excludeFlag (list) – Exclude certain ServiceAssets from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 40, “limit”: 749, “responseCode”: 200, “count”: 11, “data”: [{“id”: “Show security only of because.”, “ownedByUser”: {“id”: 482, “customerID”: 223, “userName”: “nrobinson”, “name”: “John Baker II”}, “name”: “Thomas Stephens”, “description”: “Exist party sea personal production.”, “totalCvss”: 783, “vulnerabilitiesCount”: 741, “createdTimestamp”: 1329367047, “createdByUser”: {“id”: 311, “customerID”: 423, “userName”: “nancyfranklin”, “name”: “Lauren Carter”}, “lastUpdatedTimestamp”: 1157472603, “lastUpdatedByUser”: {“id”: 131, “customerID”: 569, “userName”: “amy79”, “name”: “Jeremy Chapman”}, “deletedTimestamp”: 886050468, “deletedByUser”: {“id”: 500, “customerID”: 872, “userName”: “wryan”, “name”: “Christopher Middleton”}, “flags”: [“MERGED”], “properties”: {“additionalProperties”: “Well full partner.”}, “businessProcesses”: [{“id”: “Party pass little dark son east.”, “name”: “Joseph Hall”}], “hosts”: [{“id”: “Avoid minute book production anything region matter.”, “name”: “Jason Johnson”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Sense run paper stuff history we.”, “messageTemplate”: “Father already civil.”, “field”: “Power tend beat campaign result operation.”, “parameter”: {}, “timestamp”: 283208780}], “currentPage”: 930, “size”: 413}

`api.assets.v1.service.` `update_service_asset`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 63, “limit”: 841, “responseCode”: 200, “count”: 260, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Traditional interview determine.”, “messageTemplate”: “Loss whatever fall.”, “field”: “Off outside major first already hold former.”, “parameter”: {}, “timestamp”: 1417417346}], “currentPage”: 658, “size”: 378}

## api.assets.v1.vulnerability module

Autogenerated API

`api.assets.v1.vulnerability.` `add_asset_vulnerability`(hostID: str = None, vulnerabilityID: str = None, references: list = None, name: str = None, description: str = None, conclusion: str = None, solution: str = None, rawOutput: str = None, cvss: int = None, severity: str = None, properties: dict = None, socket: str = None, source: str = 'USER', exploitAvailable: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | hostID (str) – Specify parent host. vulnerabilityID (str) – Identifier of vulnerability (e.g. plug-in ID from vulnerability scanner). => [sw{}$-().[]“‘_/,*+#:@!?;]* references (list) – References to vulnerability (e.g. CVE number). name (str) – Name of vulnerability. Will be sanitized and no line break allowed. description (str) – Description of vulnerability. Will be sanitized. conclusion (str) – Short summary of vulnerability. Will be sanitized. solution (str) – How to fix vulnerability. Will be sanitized. rawOutput (str) – Raw output from vulnerability scan. Will be sanitized. cvss (int) – CVSS score of vulnerability (range from 0 to 10). severity (str) – Severity level of vulnerability. properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* socket (str) – Specify socket string of the vulnerability (e.g. tcp/80), or omit if not bound to a socket. source (str) – Source of the request. (default USER) exploitAvailable (bool) – Set if an exploit is available for the vulnerability.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 959, “limit”: 571, “responseCode”: 200, “count”: 634, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Glass majority from scientist.”, “messageTemplate”: “Theory affect more friend.”, “field”: “Top enough often but.”, “parameter”: {}, “timestamp”: 318194912}], “currentPage”: 655, “size”: 791}

`api.assets.v1.vulnerability.` `delete_asset_vulnerability`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks an AssetVulnerability as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 433, “limit”: 722, “responseCode”: 200, “count”: 66, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Around authority you few short any.”, “messageTemplate”: “Member mention need which medical again.”, “field”: “Focus life relate continue amount tax.”, “parameter”: {}, “timestamp”: 1096012014}], “currentPage”: 793, “size”: 936}

`api.assets.v1.vulnerability.` `get_asset_vulnerability`(id: str, includeRawOutput: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns an AssetVulnerability identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID includeRawOutput (bool) – Include raw output
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 117, “limit”: 99, “responseCode”: 200, “count”: 750, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wrong rule whole.”, “messageTemplate”: “Another final fast kind.”, “field”: “Hospital put imagine provide month street.”, “parameter”: {}, “timestamp”: 1444123727}], “currentPage”: 407, “size”: 175}

`api.assets.v1.vulnerability.` `resolve_asset_vulnerability`(id: str, resolution: str = None, comment: str = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Resolves an AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID resolution (str) – Specify resolution reason. comment (str) – Comment on why the vulnerability is resolved. => [sw{}$-().[]“‘_/,*+#:@!?;]* source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 568, “limit”: 617, “responseCode”: 200, “count”: 6, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Myself war eight suddenly.”, “messageTemplate”: “Up teach reflect market.”, “field”: “Structure yet bring people miss message.”, “parameter”: {}, “timestamp”: 414857177}], “currentPage”: 874, “size”: 119}

`api.assets.v1.vulnerability.` `search_asset_vulnerabilities`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, minimumCvss: int = None, maximumCvss: int = None, severity: list = None, resolutionCode: list = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeRawOutput: bool = 'False', includeConclusion: bool = 'False', includeSolution: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of AssetVulnerabilities defined by an AssetVulnerabilitySearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. minimumCvss (int) – Restrict search to vulnerabilities with CVSS score at least this high. maximumCvss (int) – Restrict search to vulnerabilities with CVSS score no more than this. severity (list) – Restrict search to specified severity levels. resolutionCode (list) – Restrict search to specific resolution codes. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeRawOutput (bool) – Include vulnerability rawOutput in result (default false) includeConclusion (bool) – Include vulnerability conclusion in result (default false) includeSolution (bool) – Include vulnerability solution in result (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 930, “limit”: 524, “responseCode”: 200, “count”: 860, “data”: [{“id”: “Return cup scientist spring newspaper history upon protect.”, “vulnerabilityID”: “Face what simple boy off black.”, “references”: [“Most speech practice animal keep.”], “name”: “Alexis Arroyo”, “description”: “Rest stuff there specific much paper system.”, “conclusion”: “Station moment participant throw together me nation.”, “solution”: “Require trade create.”, “rawOutput”: “Far alone available sea team since book.”, “cvss”: 533, “createdTimestamp”: 801926589, “createdByUser”: {“id”: 591, “customerID”: 941, “userName”: “urobertson”, “name”: “Mary Robinson”}, “lastUpdatedTimestamp”: 1221565363, “lastUpdatedByUser”: {“id”: 551, “customerID”: 105, “userName”: “andrewwhite”, “name”: “Taylor Martin MD”}, “deletedTimestamp”: 1465830301, “deletedByUser”: {“id”: 330, “customerID”: 203, “userName”: “masoneileen”, “name”: “Jeffery Rowland”}, “firstSeenTimestamp”: 228986394, “lastSeenTimestamp”: 525329777, “resolutionTimestamp”: 1310502630, “resolvedByUser”: {“id”: 210, “customerID”: 314, “userName”: “austin40”, “name”: “Joseph Gilbert”}, “resolutionComment”: “Six contain let company.”, “resolution”: “ACCEPTED”, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Available operation others.”}, “severity”: “critical”, “socket”: “Man happen institution sort add opportunity tonight.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Budget mean while approach gun.”, “messageTemplate”: “Account glass hour send might account box six.”, “field”: “Head middle close American.”, “parameter”: {}, “timestamp”: 1178801622}], “currentPage”: 430, “size”: 319}

`api.assets.v1.vulnerability.` `search_asset_vulnerabilities_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, resolutionCode: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of AssetVulnerabilities defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference resolutionCode (list) – Search by resolution code includeFlag (list) – Include certain BusinessProcesses in the search result based on set flags excludeFlag (list) – Exclude certain BusinessProcesses from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 455, “limit”: 371, “responseCode”: 200, “count”: 55, “data”: [{“id”: “Meet week investment.”, “vulnerabilityID”: “According buy any.”, “references”: [“Catch then along.”], “name”: “William Marsh”, “description”: “Stop break actually reduce all listen.”, “conclusion”: “Many sure this another impact.”, “solution”: “Government rest piece network design music face several.”, “rawOutput”: “So school order and.”, “cvss”: 436, “createdTimestamp”: 163472649, “createdByUser”: {“id”: 712, “customerID”: 256, “userName”: “harmonwilliam”, “name”: “Michael Mendoza”}, “lastUpdatedTimestamp”: 117354730, “lastUpdatedByUser”: {“id”: 197, “customerID”: 147, “userName”: “harveykyle”, “name”: “Cindy Pena”}, “deletedTimestamp”: 229854264, “deletedByUser”: {“id”: 464, “customerID”: 722, “userName”: “whiggins”, “name”: “David Best”}, “firstSeenTimestamp”: 1256100572, “lastSeenTimestamp”: 674874548, “resolutionTimestamp”: 992538892, “resolvedByUser”: {“id”: 486, “customerID”: 921, “userName”: “erik86”, “name”: “Jennifer West”}, “resolutionComment”: “Big different sometimes decide thank.”, “resolution”: “FALSE_POSITIVE”, “flags”: [“DETECTED_BY_CVM”], “properties”: {“additionalProperties”: “Shake cold top treatment near.”}, “severity”: “low”, “socket”: “Alone air finish government know respond can couple.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Something position hospital mean past.”, “messageTemplate”: “Often data coach cell.”, “field”: “Forget suggest share himself power.”, “parameter”: {}, “timestamp”: 57228989}], “currentPage”: 337, “size”: 238}

`api.assets.v1.vulnerability.` `update_asset_vulnerability`(id: str, addReferences: list = None, deleteReferences: list = None, name: str = None, description: str = None, conclusion: str = None, solution: str = None, rawOutput: str = None, cvss: int = None, severity: str = None, addProperties: dict = None, deleteProperties: list = None, source: str = 'USER', exploitAvailable: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID addReferences (list) – Add references to vulnerability (e.g. CVE number). deleteReferences (list) – Delete references from vulnerability. name (str) – Change vulnerability name. Will be sanitized and no line break allowed. description (str) – Change vulnerability description. Will be sanitized. conclusion (str) – Change vulnerability summary. Will be sanitized. solution (str) – Change vulnerability solution. Will be sanitized. rawOutput (str) – Change raw output from vulnerability scan. Will be sanitized. cvss (int) – Change CVSS score of vulnerability (range from 0 to 10). severity (str) – Change severity level of vulnerability. addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key. source (str) – Source of the request. (default USER) exploitAvailable (bool) – Set if an exploit is available for the vulnerability.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 255, “limit”: 302, “responseCode”: 200, “count”: 492, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Community final especially training here.”, “messageTemplate”: “Republican modern occur white station west less.”, “field”: “Site third drive.”, “parameter”: {}, “timestamp”: 854848799}], “currentPage”: 507, “size”: 353}

## Module contents